TSGPath

Struct TSGPath 

pub struct TSGPath<'a> {
    pub nodes: Vec<NodeIndex>,
    pub edges: Vec<EdgeIndex>,
    pub attributes: Vec<Attribute>,
    /* private fields */
}
A path in the transcript segment graph

A path is a sequence of nodes and edges that form a valid path through the graph. Paths can represent transcripts, exon chains, or other traversals through the graph.

Fields

nodes: Vec<NodeIndex>

The nodes in the path

edges: Vec<EdgeIndex>

The edges connecting the nodes in the path

attributes: Vec<Attribute>

Implementations

Source

impl<'a> TSGPath<'a>

pub fn builder() -> TSGPathBuilder<'a>

Create an instance of TSGPath using the builder syntax

Source

impl<'a> TSGPath<'a>

pub fn new() -> Self

Create a new empty path

pub fn graph_mut(&mut self) -> &mut Option<&'a GraphSection>

Set the graph for the path

pub fn graph(&self) -> Option<&GraphSection>

pub fn add_node(&mut self, node: NodeIndex)

Add a node to the path

pub fn add_edge(&mut self, edge: EdgeIndex)

Add an edge to the path

pub fn is_empty(&self) -> bool

Check if the path is empty

pub fn len(&self) -> usize

Get the number of nodes in the path

pub fn id(&self) -> Result<BString>

pub fn validate(&self) -> Result<()>

pub fn to_gtf(&self) -> Result<BString>

pub fn to_vcf(&self) -> Result<BString>

pub fn to_fa(&self) -> Result<BString>